Imports System
Imports System.ComponentModel
Imports System.Diagnostics
Imports System.Collections.Generic
Imports RvDataUtil

NameSpace CSL.Classes



' -- foreignKeyField=


Public Class Category


#Region "Private Variables"
    Private _CategoryID as Integer = -1
    Private _Category as String = String.Empty
    Private _SortOrder as Integer = -1
    Private _ActiveFlag as Boolean = False
    Private _CreateDate as DateTime = DateTime.MinValue
        Private _ModifyDate As DateTime = DateTime.MinValue

        Private _DefaultImageLarge As String = ""
        Private _DefaultImageThumb As String = ""
#End Region


#Region "Public Properties"
    Public Property CategoryID() As Integer
      Get
         Return _CategoryID
      End Get
      Set(ByVal value As Integer)
         _CategoryID = value
      End Set
    End Property

    Public Property Category() As String
      Get
         Return _Category
      End Get
      Set(ByVal value As String)
         _Category = value
      End Set
    End Property

    Public Property SortOrder() As Integer
      Get
         Return _SortOrder
      End Get
      Set(ByVal value As Integer)
         _SortOrder = value
      End Set
    End Property

    Public Property ActiveFlag() As Boolean
      Get
         Return _ActiveFlag
      End Get
      Set(ByVal value As Boolean)
         _ActiveFlag = value
      End Set
    End Property

    Public Property CreateDate() As DateTime
      Get
         Return _CreateDate
      End Get
      Set(ByVal value As DateTime)
         _CreateDate = value
      End Set
    End Property

    Public Property ModifyDate() As DateTime
      Get
         Return _ModifyDate
      End Get
      Set(ByVal value As DateTime)
         _ModifyDate = value
      End Set
    End Property

        Public Property DefaultImageLarge() As String
            Get
                Return _DefaultImageLarge
            End Get
            Set(ByVal value As String)
                _DefaultImageLarge = value
            End Set
        End Property
        Public Property DefaultImageThumb() As String
            Get
                Return _DefaultImageThumb
            End Get
            Set(ByVal value As String)
                _DefaultImageThumb = value
            End Set
        End Property

#End Region


    ''' <summary>
    ''' Inserts or Updates the Category object to the database.
    ''' If an insert, value of CategoryID will be updated.
    ''' </summary>
    ''' <returns>True on success, False on failure.</returns>
    Public Function Save() as Boolean
       dim strCategoryID as String = ""

       dim strError as String = ""
        Dim objUtil As New RvDataUtil.DataUtil
       objUtil.paramsClear()

       objUtil.paramsAdd("CategoryID", SqlDbType.int, CategoryID, true, 8)
       objUtil.paramsAdd("Category", SqlDbType.varchar, Category)
       objUtil.paramsAdd("SortOrder", SqlDbType.Int, SortOrder)
       if (ActiveFlag) then
           objUtil.paramsAdd("ActiveFlag", SqlDbType.Int, 1)
       else 
           objUtil.paramsAdd("ActiveFlag", SqlDbType.Int, 0)
       end if


       strCategoryID = objUtil.ExecOutput("usp_updateCategory", "@CategoryID", strError)
       If (strCategoryID = "") Or (strError <> "") Then
           HttpContext.Current.Trace.Warn("usp_updateCategory.error inserting: " & strError)
           objUtil.CloseConnection()
           Return False
       End If
       objUtil.CloseConnection()
       objUtil = Nothing

       If IsNumeric(strCategoryID) Then
           CategoryID = CInt(strCategoryID)
       End If
       Return True 


    End Function



End Class




Public Class CategoryList
    Inherits List(Of Category)

        Public Sub New()
        End Sub

End Class





Public Class CategoryManager


#Region "Public Methods"

    ''' <summary>
    ''' Gets a list with all Category objects in the database.
    ''' </summary>
    ''' <returns>A list with all Category from the database when the database contains any, or null otherwise.</returns>
    Public Shared Function GetList() As CategoryList
        Dim tempList As CategoryList = Nothing
        Dim objUtil As New RvDataUtil.DataUtil
        Dim strError as String = ""
        objUtil.paramsClear()
        Using myReader As SqlDataReader = objUtil.ExecDataReader("usp_getCategory", strError)
            If (strError <> "") Then
                 HttpContext.Current.Trace.Warn("CategoryManager.GetList().error=" & strError)
            End If
            If Not IsNothing(myReader) AndAlso myReader.HasRows Then
                tempList = New CategoryList
                Do While myReader.Read()
                  tempList.Add(FillDataRecord(myReader))
                Loop
                myReader.Close()
            End If
        End Using
        objUtil.CloseConnection()
        Return tempList
    End Function


    ''' <summary>
    ''' Gets a single Category from the database.
    ''' </summary>
    ''' <param name="CategoryID">The CategoryID of the Category in the database.</param>
    ''' <returns>A Category object when the CategoryID exists in the database, or null otherwise.</returns>
    Public Shared Function GetItem(ByVal CategoryID As Integer) As Category
        Dim myCategory As Category = Nothing
        Dim strError as String = ""
        Dim objUtil As New RvDataUtil.DataUtil
        objUtil.paramsClear()
        objUtil.paramsAdd("CategoryID", SqlDbType.Int, CategoryID)
        Using myReader As SqlDataReader = objUtil.ExecDataReader("usp_getCategory", strError)
            If (strError <> "") Then
                 HttpContext.Current.Trace.Warn("CategoryManager.GetItem().error=" & strError)
            End If
            If Not IsNothing(myReader) AndAlso myReader.HasRows Then
                myCategory = New Category()
                Do While myReader.Read()
                    myCategory = FillDataRecord(myReader)
                Loop
                myReader.Close()
            End If
        End Using
        objUtil.CloseConnection()
        Return myCategory
    End Function


#End Region


    ''' <summary>
    ''' Initializes a new instance of the Category class and fills it with the data fom the IDataRecord.
    ''' </summary>
    Private Shared Function FillDataRecord(ByVal myDataRecord As IDataRecord) As Category
            Dim myCategory As Category = New Category()

            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("CategoryID"))) Then
               myCategory.CategoryID = myDataRecord.Item("CategoryID")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("Category"))) Then
               myCategory.Category = myDataRecord.Item("Category")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("SortOrder"))) Then
               myCategory.SortOrder = myDataRecord.Item("SortOrder")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("ActiveFlag"))) Then
               myCategory.ActiveFlag = myDataRecord.Item("ActiveFlag")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("CreateDate"))) Then
               myCategory.CreateDate = myDataRecord.Item("CreateDate")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("ModifyDate"))) Then
               myCategory.ModifyDate = myDataRecord.Item("ModifyDate")
            End If

            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("DefaultImageLarge"))) Then
                myCategory.DefaultImageLarge = myDataRecord.Item("DefaultImageLarge")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("DefaultImageThumb"))) Then
                myCategory.DefaultImageThumb = myDataRecord.Item("DefaultImageThumb")
            End If
            Return myCategory
    End Function


End Class




End NameSpace

