Imports System
Imports System.ComponentModel
Imports System.Diagnostics
Imports System.Collections.Generic
Imports RvDataUtil

NameSpace CSL.Classes



' -- foreignKeyField=


Public Class PageContent


#Region "Private Variables"
    Private _PageContentID as Integer = -1
    Private _PageName as String = String.Empty
    Private _Headline as String = String.Empty
    Private _MetaDescription as String = String.Empty
    Private _MetaKeywords as String = String.Empty
    Private _Info as String = String.Empty
    Private _Active as Boolean = False
    Private _CreateDate as DateTime = DateTime.MinValue
    Private _CreatedBy as String = String.Empty
    Private _ModifyDate as DateTime = DateTime.MinValue
    Private _ModifiedBy as String = String.Empty
    Private _WebsiteID as Integer = -1
    Private _AllwebsitesFlag as Boolean = False
#End Region


#Region "Public Properties"
    Public Property PageContentID() As Integer
      Get
         Return _PageContentID
      End Get
      Set(ByVal value As Integer)
         _PageContentID = value
      End Set
    End Property

    Public Property PageName() As String
      Get
         Return _PageName
      End Get
      Set(ByVal value As String)
         _PageName = value
      End Set
    End Property

    Public Property Headline() As String
      Get
         Return _Headline
      End Get
      Set(ByVal value As String)
         _Headline = value
      End Set
    End Property

    Public Property MetaDescription() As String
      Get
         Return _MetaDescription
      End Get
      Set(ByVal value As String)
         _MetaDescription = value
      End Set
    End Property

    Public Property MetaKeywords() As String
      Get
         Return _MetaKeywords
      End Get
      Set(ByVal value As String)
         _MetaKeywords = value
      End Set
    End Property

    Public Property Info() As String
      Get
         Return _Info
      End Get
      Set(ByVal value As String)
         _Info = value
      End Set
    End Property

    Public Property Active() As Boolean
      Get
         Return _Active
      End Get
      Set(ByVal value As Boolean)
         _Active = value
      End Set
    End Property

    Public Property CreateDate() As DateTime
      Get
         Return _CreateDate
      End Get
      Set(ByVal value As DateTime)
         _CreateDate = value
      End Set
    End Property

    Public Property CreatedBy() As String
      Get
         Return _CreatedBy
      End Get
      Set(ByVal value As String)
         _CreatedBy = value
      End Set
    End Property

    Public Property ModifyDate() As DateTime
      Get
         Return _ModifyDate
      End Get
      Set(ByVal value As DateTime)
         _ModifyDate = value
      End Set
    End Property

    Public Property ModifiedBy() As String
      Get
         Return _ModifiedBy
      End Get
      Set(ByVal value As String)
         _ModifiedBy = value
      End Set
    End Property

    Public Property WebsiteID() As Integer
      Get
         Return _WebsiteID
      End Get
      Set(ByVal value As Integer)
         _WebsiteID = value
      End Set
    End Property

    Public Property AllwebsitesFlag() As Boolean
      Get
         Return _AllwebsitesFlag
      End Get
      Set(ByVal value As Boolean)
         _AllwebsitesFlag = value
      End Set
    End Property

#End Region


    ''' <summary>
    ''' Inserts or Updates the PageContent object to the database.
    ''' If an insert, value of PageContentID will be updated.
    ''' </summary>
    ''' <returns>True on success, False on failure.</returns>
    Public Function Save() as Boolean
       dim strPageContentID as String = ""

       dim strError as String = ""
        Dim objUtil As New RvDataUtil.DataUtil
       objUtil.paramsClear()

       objUtil.paramsAdd("PageContentID", SqlDbType.int, PageContentID, true, 8)
       objUtil.paramsAdd("PageName", SqlDbType.varchar, PageName)
       objUtil.paramsAdd("Headline", SqlDbType.varchar, Headline)
       objUtil.paramsAdd("MetaDescription", SqlDbType.varchar, MetaDescription)
       objUtil.paramsAdd("MetaKeywords", SqlDbType.varchar, MetaKeywords)
       objUtil.paramsAdd("Info", SqlDbType.text, Info)
       if (Active) then
           objUtil.paramsAdd("Active", SqlDbType.Int, 1)
       else 
           objUtil.paramsAdd("Active", SqlDbType.Int, 0)
       end if
       objUtil.paramsAdd("WebsiteID", SqlDbType.Int, WebsiteID)
       if (AllwebsitesFlag) then
           objUtil.paramsAdd("AllwebsitesFlag", SqlDbType.Int, 1)
       else 
           objUtil.paramsAdd("AllwebsitesFlag", SqlDbType.Int, 0)
       end if


       strPageContentID = objUtil.ExecOutput("usp_updatePageContent", "@PageContentID", strError)
       If (strPageContentID = "") Or (strError <> "") Then
           HttpContext.Current.Trace.Warn("usp_updatePageContent.error inserting: " & strError)
           objUtil.CloseConnection()
           Return False
       End If
       objUtil.CloseConnection()
       objUtil = Nothing

       If IsNumeric(strPageContentID) Then
           PageContentID = CInt(strPageContentID)
       End If
       Return True 


    End Function



End Class




Public Class PageContentList
    Inherits List(Of PageContent)

        Public Sub New()
        End Sub

End Class





Public Class PageContentManager


#Region "Public Methods"

    ''' <summary>
    ''' Gets a list with all PageContent objects in the database.
    ''' </summary>
    ''' <returns>A list with all PageContent from the database when the database contains any, or null otherwise.</returns>
    Public Shared Function GetList() As PageContentList
        Dim tempList As PageContentList = Nothing
        Dim objUtil As New RvDataUtil.DataUtil
        Dim strError as String = ""
        objUtil.paramsClear()
        Using myReader As SqlDataReader = objUtil.ExecDataReader("usp_getPageContent", strError)
            If (strError <> "") Then
                 HttpContext.Current.Trace.Warn("PageContentManager.GetList().error=" & strError)
            End If
            If Not IsNothing(myReader) AndAlso myReader.HasRows Then
                tempList = New PageContentList
                Do While myReader.Read()
                  tempList.Add(FillDataRecord(myReader))
                Loop
                myReader.Close()
            End If
        End Using
        objUtil.CloseConnection()
        Return tempList
    End Function


    ''' <summary>
    ''' Gets a single PageContent from the database.
    ''' </summary>
    ''' <param name="PageContentID">The PageContentID of the PageContent in the database.</param>
    ''' <returns>A PageContent object when the PageContentID exists in the database, or null otherwise.</returns>
    Public Shared Function GetItem(ByVal PageContentID As Integer) As PageContent
        Dim myPageContent As PageContent = Nothing
        Dim strError as String = ""
        Dim objUtil As New RvDataUtil.DataUtil
        objUtil.paramsClear()
        objUtil.paramsAdd("PageContentID", SqlDbType.Int, PageContentID)
        Using myReader As SqlDataReader = objUtil.ExecDataReader("usp_getPageContent", strError)
            If (strError <> "") Then
                 HttpContext.Current.Trace.Warn("PageContentManager.GetItem().error=" & strError)
            End If
            If Not IsNothing(myReader) AndAlso myReader.HasRows Then
                myPageContent = New PageContent()
                Do While myReader.Read()
                    myPageContent = FillDataRecord(myReader)
                Loop
                myReader.Close()
            End If
        End Using
        objUtil.CloseConnection()
        Return myPageContent
    End Function


#End Region


    ''' <summary>
    ''' Initializes a new instance of the PageContent class and fills it with the data fom the IDataRecord.
    ''' </summary>
    Private Shared Function FillDataRecord(ByVal myDataRecord As IDataRecord) As PageContent
            Dim myPageContent As PageContent = New PageContent()

            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("PageContentID"))) Then
               myPageContent.PageContentID = myDataRecord.Item("PageContentID")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("PageName"))) Then
               myPageContent.PageName = myDataRecord.Item("PageName")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("Headline"))) Then
               myPageContent.Headline = myDataRecord.Item("Headline")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("MetaDescription"))) Then
               myPageContent.MetaDescription = myDataRecord.Item("MetaDescription")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("MetaKeywords"))) Then
               myPageContent.MetaKeywords = myDataRecord.Item("MetaKeywords")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("Info"))) Then
               myPageContent.Info = myDataRecord.Item("Info")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("Active"))) Then
               myPageContent.Active = myDataRecord.Item("Active")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("CreateDate"))) Then
               myPageContent.CreateDate = myDataRecord.Item("CreateDate")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("CreatedBy"))) Then
               myPageContent.CreatedBy = myDataRecord.Item("CreatedBy")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("ModifyDate"))) Then
               myPageContent.ModifyDate = myDataRecord.Item("ModifyDate")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("ModifiedBy"))) Then
               myPageContent.ModifiedBy = myDataRecord.Item("ModifiedBy")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("WebsiteID"))) Then
               myPageContent.WebsiteID = myDataRecord.Item("WebsiteID")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("AllwebsitesFlag"))) Then
               myPageContent.AllwebsitesFlag = myDataRecord.Item("AllwebsitesFlag")
            End If
            Return myPageContent
    End Function


End Class




End NameSpace

