Imports System
Imports System.ComponentModel
Imports System.Diagnostics
Imports System.Collections.Generic
Imports RvDataUtil

NameSpace CSL.Classes



' -- foreignKeyField=CategoryID


Public Class Portfolio


#Region "Private Variables"
    Private _PortfolioID as Integer = -1
    Private _CategoryID as Integer = -1
    Private _PortfolioName as String = String.Empty
    Private _Image_thumb as String = String.Empty
    Private _Image_large as String = String.Empty
    Private _DefaultCategoryImageFlag as Boolean = False
    Private _PortfolioDescription as String = String.Empty
    Private _Tags as String = String.Empty
    Private _SortOrder as Integer = -1
    Private _ActiveFlag as Boolean = False
    Private _CreateDate as DateTime = DateTime.MinValue
    Private _ModifyDate as DateTime = DateTime.MinValue
#End Region


#Region "Public Properties"
    Public Property PortfolioID() As Integer
      Get
         Return _PortfolioID
      End Get
      Set(ByVal value As Integer)
         _PortfolioID = value
      End Set
    End Property

    Public Property CategoryID() As Integer
      Get
         Return _CategoryID
      End Get
      Set(ByVal value As Integer)
         _CategoryID = value
      End Set
    End Property

    Public Property PortfolioName() As String
      Get
         Return _PortfolioName
      End Get
      Set(ByVal value As String)
         _PortfolioName = value
      End Set
    End Property

    Public Property Image_thumb() As String
      Get
         Return _Image_thumb
      End Get
      Set(ByVal value As String)
         _Image_thumb = value
      End Set
    End Property

    Public Property Image_large() As String
      Get
         Return _Image_large
      End Get
      Set(ByVal value As String)
         _Image_large = value
      End Set
    End Property

    Public Property DefaultCategoryImageFlag() As Boolean
      Get
         Return _DefaultCategoryImageFlag
      End Get
      Set(ByVal value As Boolean)
         _DefaultCategoryImageFlag = value
      End Set
    End Property

    Public Property PortfolioDescription() As String
      Get
         Return _PortfolioDescription
      End Get
      Set(ByVal value As String)
         _PortfolioDescription = value
      End Set
    End Property

    Public Property Tags() As String
      Get
         Return _Tags
      End Get
      Set(ByVal value As String)
         _Tags = value
      End Set
    End Property

    Public Property SortOrder() As Integer
      Get
         Return _SortOrder
      End Get
      Set(ByVal value As Integer)
         _SortOrder = value
      End Set
    End Property

    Public Property ActiveFlag() As Boolean
      Get
         Return _ActiveFlag
      End Get
      Set(ByVal value As Boolean)
         _ActiveFlag = value
      End Set
    End Property

    Public Property CreateDate() As DateTime
      Get
         Return _CreateDate
      End Get
      Set(ByVal value As DateTime)
         _CreateDate = value
      End Set
    End Property

    Public Property ModifyDate() As DateTime
      Get
         Return _ModifyDate
      End Get
      Set(ByVal value As DateTime)
         _ModifyDate = value
      End Set
    End Property

#End Region


    ''' <summary>
    ''' Inserts or Updates the Portfolio object to the database.
    ''' If an insert, value of PortfolioID will be updated.
    ''' </summary>
    ''' <returns>True on success, False on failure.</returns>
    Public Function Save() as Boolean
       dim strPortfolioID as String = ""

       dim strError as String = ""
        Dim objUtil As New RvDataUtil.DataUtil
       objUtil.paramsClear()

       objUtil.paramsAdd("PortfolioID", SqlDbType.int, PortfolioID, true, 8)
       objUtil.paramsAdd("CategoryID", SqlDbType.Int, CategoryID)
       objUtil.paramsAdd("PortfolioName", SqlDbType.varchar, PortfolioName)
       objUtil.paramsAdd("Image_thumb", SqlDbType.varchar, Image_thumb)
       objUtil.paramsAdd("Image_large", SqlDbType.varchar, Image_large)
       if (DefaultCategoryImageFlag) then
           objUtil.paramsAdd("DefaultCategoryImageFlag", SqlDbType.Int, 1)
       else 
           objUtil.paramsAdd("DefaultCategoryImageFlag", SqlDbType.Int, 0)
       end if
       objUtil.paramsAdd("PortfolioDescription", SqlDbType.varchar, PortfolioDescription)
       objUtil.paramsAdd("Tags", SqlDbType.varchar, Tags)
       objUtil.paramsAdd("SortOrder", SqlDbType.Int, SortOrder)
       if (ActiveFlag) then
           objUtil.paramsAdd("ActiveFlag", SqlDbType.Int, 1)
       else 
           objUtil.paramsAdd("ActiveFlag", SqlDbType.Int, 0)
       end if


       strPortfolioID = objUtil.ExecOutput("usp_updatePortfolio", "@PortfolioID", strError)
       If (strPortfolioID = "") Or (strError <> "") Then
           HttpContext.Current.Trace.Warn("usp_updatePortfolio.error inserting: " & strError)
           objUtil.CloseConnection()
           Return False
       End If
       objUtil.CloseConnection()
       objUtil = Nothing

       If IsNumeric(strPortfolioID) Then
           PortfolioID = CInt(strPortfolioID)
       End If
       Return True 


    End Function



End Class




Public Class PortfolioList
    Inherits List(Of Portfolio)

        Public Sub New()
        End Sub

End Class





Public Class PortfolioManager


#Region "Public Methods"

    ''' <summary>
    ''' Gets a list with all Portfolio objects in the database.
    ''' </summary>
    ''' <returns>A list with all Portfolio from the database when the database contains any, or null otherwise.</returns>
    Public Shared Function GetList(ByVal CategoryID as Integer) As PortfolioList
        Dim tempList As PortfolioList = Nothing
        Dim objUtil As New RvDataUtil.DataUtil
        Dim strError as String = ""
        objUtil.paramsClear()
        objUtil.paramsAdd("@CategoryID", SqlDbType.Int, CategoryID)
        Using myReader As SqlDataReader = objUtil.ExecDataReader("usp_getPortfolio", strError)
            If (strError <> "") Then
                 HttpContext.Current.Trace.Warn("PortfolioManager.GetList().error=" & strError)
            End If
            If Not IsNothing(myReader) AndAlso myReader.HasRows Then
                tempList = New PortfolioList
                Do While myReader.Read()
                  tempList.Add(FillDataRecord(myReader))
                Loop
                myReader.Close()
            End If
        End Using
        objUtil.CloseConnection()
        Return tempList
    End Function


    ''' <summary>
    ''' Gets a single Portfolio from the database.
    ''' </summary>
    ''' <param name="PortfolioID">The PortfolioID of the Portfolio in the database.</param>
    ''' <returns>A Portfolio object when the PortfolioID exists in the database, or null otherwise.</returns>
    Public Shared Function GetItem(ByVal PortfolioID As Integer) As Portfolio
        Dim myPortfolio As Portfolio = Nothing
        Dim strError as String = ""
        Dim objUtil As New RvDataUtil.DataUtil
        objUtil.paramsClear()
        objUtil.paramsAdd("PortfolioID", SqlDbType.Int, PortfolioID)
        Using myReader As SqlDataReader = objUtil.ExecDataReader("usp_getPortfolio", strError)
            If (strError <> "") Then
                 HttpContext.Current.Trace.Warn("PortfolioManager.GetItem().error=" & strError)
            End If
            If Not IsNothing(myReader) AndAlso myReader.HasRows Then
                myPortfolio = New Portfolio()
                Do While myReader.Read()
                    myPortfolio = FillDataRecord(myReader)
                Loop
                myReader.Close()
            End If
        End Using
        objUtil.CloseConnection()
        Return myPortfolio
    End Function


#End Region


    ''' <summary>
    ''' Initializes a new instance of the Portfolio class and fills it with the data fom the IDataRecord.
    ''' </summary>
    Private Shared Function FillDataRecord(ByVal myDataRecord As IDataRecord) As Portfolio
            Dim myPortfolio As Portfolio = New Portfolio()

            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("PortfolioID"))) Then
               myPortfolio.PortfolioID = myDataRecord.Item("PortfolioID")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("CategoryID"))) Then
               myPortfolio.CategoryID = myDataRecord.Item("CategoryID")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("PortfolioName"))) Then
               myPortfolio.PortfolioName = myDataRecord.Item("PortfolioName")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("Image_thumb"))) Then
               myPortfolio.Image_thumb = myDataRecord.Item("Image_thumb")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("Image_large"))) Then
               myPortfolio.Image_large = myDataRecord.Item("Image_large")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("DefaultCategoryImageFlag"))) Then
               myPortfolio.DefaultCategoryImageFlag = myDataRecord.Item("DefaultCategoryImageFlag")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("PortfolioDescription"))) Then
               myPortfolio.PortfolioDescription = myDataRecord.Item("PortfolioDescription")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("Tags"))) Then
               myPortfolio.Tags = myDataRecord.Item("Tags")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("SortOrder"))) Then
               myPortfolio.SortOrder = myDataRecord.Item("SortOrder")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("ActiveFlag"))) Then
               myPortfolio.ActiveFlag = myDataRecord.Item("ActiveFlag")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("CreateDate"))) Then
               myPortfolio.CreateDate = myDataRecord.Item("CreateDate")
            End If
            If (Not myDataRecord.IsDBNull(myDataRecord.GetOrdinal("ModifyDate"))) Then
               myPortfolio.ModifyDate = myDataRecord.Item("ModifyDate")
            End If
            Return myPortfolio
    End Function


End Class




End NameSpace

